pub struct Name<'a> { /* private fields */ }Expand description
Holds information about a particular domain name
Implementations
Sourceimpl<'a> Name<'a>
impl<'a> Name<'a>
Sourcepub fn has_known_suffix(&self) -> bool
pub fn has_known_suffix(&self) -> bool
Whether the suffix of the domain name is in the Public Suffix List
Sourcepub fn is_icann(&self) -> bool
pub fn is_icann(&self) -> bool
Whether this an ICANN delegated suffix
ICANN domains are those delegated by ICANN or part of the IANA root zone database
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Whether this is a private party delegated suffix
PRIVATE domains are amendments submitted by the domain holder, as an expression of how they operate their domain security policy