DnsName

Trait DnsName 

pub trait DnsName {
    // Required method
    fn parse_dns_name<'a>(&self, name: &'a str) -> Result<'a, Name<'a>>;
}
Parses any arbitrary string that can be used as a key in a DNS database

Required Methods

fn parse_dns_name<'a>(&self, name: &'a str) -> Result<'a, Name<'a>>

This method allows additional characters, like underscores, typically allowed in DNS labels but are not usually allowed by domain registries. For that use parse_domain_name instead.

Implementors

Source

impl<T> DnsName for T
where T: List,